/*
 * DC jQuery Accordion - jQuery accordion menu widget
 * Copyright (c) 2011 Design Chemical
 *
 * Dual licensed under the MIT and GPL licenses:
 * 	http://www.opensource.org/licenses/mit-license.php
 * 	http://www.gnu.org/licenses/gpl.html
 *
 */
(function($){

	//define the new for the plugin ans how to call it	

	$.fn.dcAccordion = function(options) {
		//set default options  
		var defaults = {
			classParent	 : 'dcjq-parent',
			classActive	 : 'active',
			eventType	 : 'click',
			hoverDelay	 : 300,
			menuClose     : true,
			autoClose    : true,
			speed        : 'slow',
			saveState	 : true,
			disableLink	 : true
		};
		
		//call in the default otions
		var options = $.extend(defaults, options);
		var $dcAccordionItem = this;

		//act upon the element that is passed into the design    
		return $dcAccordionItem.each(function(options){

			setUpAccordion();

			if(defaults.saveState == true){
				cookieId = $(this).parent().attr('id');
				checkCookie();
			}
			resetAccordion();
			
			if(defaults.eventType == 'hover'){

				var config = {
					sensitivity: 2, // number = sensitivity threshold (must be 1 or higher)
					interval: defaults.hoverDelay, // number = milliseconds for onMouseOver polling interval
					over: linkOver, // function = onMouseOver callback (REQUIRED)
					timeout: defaults.hoverDelay, // number = milliseconds delay before onMouseOut
					out: linkOut // function = onMouseOut callback (REQUIRED)
				};
				$('li a',$dcAccordionItem).hoverIntent(config);
				
				var configMenu = {
					sensitivity: 2, // number = sensitivity threshold (must be 1 or higher)
					interval: 1000, // number = milliseconds for onMouseOver polling interval
					over: menuOver, // function = onMouseOver callback (REQUIRED)
					timeout: 1000, // number = milliseconds delay before onMouseOut
					out: menuOut // function = onMouseOut callback (REQUIRED)
				};
				$($dcAccordionItem).hoverIntent(configMenu);
				
				// Disable parent links
				if(defaults.disableLink == true){
					$('li a',$dcAccordionItem).click(function(e){
						if($(this).next('ul').length >0){
							e.preventDefault();
						}
					});
				}

			} else {
			
				$('li a',$dcAccordionItem).click(function(e){

					$activeLi = $(this).parent('li');
					$parentsLi = $activeLi.parents('li');
					$parentsUl = $activeLi.parents('ul');
			
					// Prevent browsing to link if has child links
					if(defaults.disableLink == true){
						if($(this).next('ul').length >0){
							e.preventDefault();
						}
					}
				
					// Auto close sibling menus
					if(defaults.autoClose == true){
						autoCloseAccordion($parentsLi, $parentsUl);
					}
				
					if ($('> ul',$activeLi).is(':visible')){
						$('ul',$activeLi).slideUp(defaults.speed);
						$('a',$activeLi).removeClass(defaults.classActive);
					} else {
						$(this).next().slideToggle(defaults.speed);
						$('> a',$activeLi).addClass(defaults.classActive);
					}

					// Write cookie if save state is on
					if(defaults.saveState == true){
						createCookie();
				}
			});
			}
			// Set up accordion
			function setUpAccordion(){
				$arrow = '<span class="dcjq-icon"></span>';
				$('> ul',$dcAccordionItem).show();
				$('li',$dcAccordionItem).each(function(){
					var classParentLi = defaults.classParent+'-li';
					if($('> ul',this).length > 0){
						$(this).addClass(classParentLi);
						$('> a',this).addClass(defaults.classParent).append($arrow);
					}
				});	
				$('> ul',$dcAccordionItem).hide();
			}
		});
		
		function linkOver(){

			$activeLi = $(this).parent('li');
			$parentsLi = $activeLi.parents('li');
			$parentsUl = $activeLi.parents('ul');

			// Auto close sibling menus
			if(defaults.autoClose == true){
					autoCloseAccordion($parentsLi, $parentsUl);
				}

			if ($('> ul',$activeLi).is(':visible')){
					$('ul',$activeLi).slideUp(defaults.speed);
					$('a',$activeLi).removeClass(defaults.classActive);
				} else {
					$(this).next().slideToggle(defaults.speed);
					$('> a',$activeLi).addClass(defaults.classActive);
				}

			// Write cookie if save state is on
			if(defaults.saveState == true){
				createCookie();
			}

		}
		
		function linkOut(){
		}
		
		function menuOver(){
		}
		
		function menuOut(){
			if(defaults.menuClose == true){
				$('ul',$dcAccordionItem).slideUp(defaults.speed);
				// Reset active links
				$('a',$dcAccordionItem).removeClass(defaults.classActive);
				createCookie();
			}
		}
		
		// Auto-Close Open Menu Items
		function autoCloseAccordion($parentsLi, $parentsUl){
			$('ul',$dcAccordionItem).not($parentsUl).slideUp(defaults.speed);
			// Reset active links
			$('a',$dcAccordionItem).removeClass(defaults.classActive);
			$('> a',$parentsLi).addClass(defaults.classActive);
		}
		
		// Retrieve cookie value and set active items
		function checkCookie(){
			var cookieVal = $.cookie(cookieId);
			if(cookieVal != null){
				// create array from cookie string
				var activeArray = cookieVal.split(',');
				$.each(activeArray, function(index,value){
					var $cookieLi = $('li:eq('+value+')',$dcAccordionItem);
					$('> a',$cookieLi).addClass(defaults.classActive);
					var $parentsLi = $cookieLi.parents('li');
					$('> a',$parentsLi).addClass(defaults.classActive);
				});
			}
		}
		
		// Reset accordion using active links
		function resetAccordion(){
			$('ul',$dcAccordionItem).hide();
			$allActiveLi = $('a.'+defaults.classActive,$dcAccordionItem);
			$allActiveLi.next().show();
		}
		
		// Write cookie
		function createCookie(){
			var activeIndex = [];
			// Create array of active items index value
			$('li a.active',$dcAccordionItem).each(function(i){
				var $arrayItem = $(this).parent('li');
				var itemIndex = $('li',$dcAccordionItem).index($arrayItem);
					activeIndex.push(itemIndex);
				});
			// Store in cookie
			$.cookie(cookieId, activeIndex, { path: '/' });
		}
	};
})(jQuery);